/*
 * Copyright 2012-2017 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.gateway.service.schema;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.IOException;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;

import org.eclipse.jetty.client.api.ContentResponse;
import org.eclipse.jetty.http.HttpMethod;
import org.eclipse.jetty.http.HttpStatus;
import org.junit.Test;

import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.redhat.thermostat.common.json.JsonUtil;
import com.redhat.thermostat.common.yaml.YamlToJson;
import com.redhat.thermostat.gateway.tests.integration.IntegrationTest;

public class SchemaIntegrationTest extends IntegrationTest {

    private static final String serviceName = "schema";

    public SchemaIntegrationTest() {
        super(serviceName);
    }

    @Test
    public void testGoodYaml() throws InterruptedException, ExecutionException, TimeoutException, IOException {
        final ContentResponse resp = get("/fullapi-swagger.yaml");
        final YamlToJson y2j = new YamlToJson();
        final JsonObject json = y2j.yamlToJsonObject(resp.getContentAsString());
        verifyApi(json);
    }

    @Test
    public void testGoodJson() throws InterruptedException, ExecutionException, TimeoutException {
        final ContentResponse resp = get("/fullapi-swagger.json");
        final JsonObject json = new JsonParser().parse(resp.getContentAsString()).getAsJsonObject();
        verifyApi(json);
    }

    private void verifyApi(JsonObject obj) {
        final String title = JsonUtil.fetch(obj, "info.title").getAsString();
        assertNotNull(title);
        assertTrue(title.contains("Thermostat" ));
        final JsonObject paths = obj.get("paths").getAsJsonObject();
        assertNotNull(paths);
        assertFalse(paths.entrySet().isEmpty());
    }

    @Test
    public void testBad() throws InterruptedException, ExecutionException, TimeoutException {
        getBad("/fullapi-swagge.yaml");
    }

    protected ContentResponse get(final String path) throws InterruptedException, ExecutionException, TimeoutException {
        ContentResponse response = client.newRequest(resourceUrl + path).method(HttpMethod.GET).send();
        assertEquals(HttpStatus.OK_200, response.getStatus());
        return response;
    }

    protected ContentResponse getBad(final String path) throws InterruptedException, ExecutionException, TimeoutException {
        ContentResponse response = client.newRequest(resourceUrl + path).method(HttpMethod.GET).send();
        assertEquals(HttpStatus.NOT_FOUND_404, response.getStatus());
        return response;
    }
}